package de.hftstuttgart.unifiedticketing.core;

import de.hftstuttgart.unifiedticketing.systems.github.GithubTicketSystemBuilder;
import de.hftstuttgart.unifiedticketing.systems.gitlab.GitlabTicketSystemBuilder;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * This class is where for each supported system a method is placed, that returns a new Builder instance for it.
 */
public class RegisteredSystems
{
    private static Logger logger = Logging.getLogger(RegisteredSystems.class.getName());

    private static RegisteredSystems instance = null;

    protected RegisteredSystems() { }

    protected static RegisteredSystems getInstance()
    {
        if (instance == null)
        {
            instance = new RegisteredSystems();
            logger.log(Level.FINEST, "Singleton instance created");
        }
        return instance;
    }

    /**
     * Starts the builder mechanism for a GitHub connection
     */
    public GithubTicketSystemBuilder github()
    {
        return new GithubTicketSystemBuilder();
    }

    /**
     * Starts the builder mechanism for a GitLab connection
     */
    public GitlabTicketSystemBuilder gitlab()
    {
        return new GitlabTicketSystemBuilder();
    }
}
